@@ -193,8 +193,6 @@ EXCLUDE = (
   "lib/circogen/circular.c",
   "lib/circogen/circular.h",
   "lib/circogen/circularinit.c",
-  "lib/circogen/deglist.c",
-  "lib/circogen/deglist.h",
   "lib/circogen/edgelist.c",
   "lib/circogen/edgelist.h",
   "lib/circogen/nodelist.c",
@@ -476,7 +474,6 @@ EXCLUDE = (
   "lib/ortho/ortho.c",
   "lib/ortho/ortho.h",
   "lib/ortho/partition.c",
-  "lib/ortho/partition.h",
   "lib/ortho/rawgraph.c",
   "lib/ortho/rawgraph.h",
   "lib/ortho/sgraph.c",
@@ -518,8 +515,6 @@ EXCLUDE = (
   "lib/rbtree/test_red_black_tree.c",
   "lib/sfdpgen/Multilevel.c",
   "lib/sfdpgen/Multilevel.h",
-  "lib/sfdpgen/PriorityQueue.c",
-  "lib/sfdpgen/PriorityQueue.h",
   "lib/sfdpgen/post_process.c",
   "lib/sfdpgen/post_process.h",
   "lib/sfdpgen/sfdp.h",
