@@ -1,3 +1,8 @@
+/**
+ * @file
+ * @brief DOT-<a href=https://en.wikipedia.org/wiki/GXL>GXL</a> convert subroutines
+ */
+
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,15 +13,16 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-
+#include <cgraph/alloc.h>
+#include <common/types.h>
+#include <common/utils.h>
 #include "convert.h"
 #include <ctype.h>
-#include <stddef.h>
+#include <stdio.h>
+#include <stdlib.h>
 
 #define SMALLBUF    128
 
-#define NEW(t)      malloc(sizeof(t))
-#define N_NEW(n,t)  calloc((n),sizeof(t))
 #define EMPTY(s)	((s == 0) || (*s == '\0'))
 #define SLEN(s)     (sizeof(s)-1)
 
@@ -41,7 +47,7 @@
 typedef struct {
     Agrec_t h;
     int written;
-} Agnodeinfo_t;
+} Local_Agnodeinfo_t;
 
 static int Level;		/* level of tabs */
 static Agsym_t *Tailport, *Headport;
@@ -54,7 +60,10 @@ typedef struct {
 
 static namev_t *make_nitem(Dt_t * d, namev_t * objp, Dtdisc_t * disc)
 {
-    namev_t *np = NEW(namev_t);
+    (void)d;
+    (void)disc;
+
+    namev_t *np = gv_alloc(sizeof(*np));
     np->name = objp->name;
     np->unique_name = 0;
     return np;
@@ -62,6 +71,9 @@ static namev_t *make_nitem(Dt_t * d, namev_t * objp, Dtdisc_t * disc)
 
 static void free_nitem(Dt_t * d, namev_t * np, Dtdisc_t * disc)
 {
+    (void)d;
+    (void)disc;
+
     free(np);
 }
 
@@ -84,6 +96,9 @@ typedef struct {
 
 static void free_iditem(Dt_t * d, idv_t * idp, Dtdisc_t * disc)
 {
+    (void)d;
+    (void)disc;
+
     free(idp->name);
     free(idp);
 }
@@ -139,112 +154,22 @@ static int legalGXLName(char *id)
     return 1;
 }
 
-/* return true if *s points to &[A-Za-z]+;      (e.g. &Ccedil; )
- *                          or &#[0-9]*;        (e.g. &#38; )
- *                          or &#x[0-9a-fA-F]*; (e.g. &#x6C34; )
- */
-static int xml_isentity(char *s)
-{
-    s++;			/* already known to be '&' */
-    if (*s == ';') { // '&;' is not a valid entity
-	return 0;
-    }
-    if (*s == '#') {
-	s++;
-	if (*s == 'x' || *s == 'X') {
-	    s++;
-	    while ((*s >= '0' && *s <= '9')
-		   || (*s >= 'a' && *s <= 'f')
-		   || (*s >= 'A' && *s <= 'F'))
-		s++;
-	} else {
-	    while (*s >= '0' && *s <= '9')
-		s++;
-	}
-    } else {
-	while ((*s >= 'a' && *s <= 'z')
-	       || (*s >= 'A' && *s <= 'Z'))
-	    s++;
-    }
-    if (*s == ';')
-	return 1;
-    return 0;
+// `fputs` wrapper to handle the difference in calling convention to what
+// `xml_escape`’s `cb` expects
+static inline int put(void *stream, const char *s) {
+  return fputs(s, stream);
 }
 
-static char *_xml_string(char *s, int notURL)
-{
-    static char *buf = NULL;
-    static int bufsize = 0;
-    char *p, *sub, *prev = NULL;
-    int len, pos = 0;
-
-    if (!buf) {
-	bufsize = 64;
-	buf = N_NEW(bufsize, char);
-    }
-
-    p = buf;
-    while (s && *s) {
-	if (pos > (bufsize - 8)) {
-	    bufsize *= 2;
-	    buf = realloc(buf, bufsize);
-	    p = buf + pos;
-	}
-	/* escape '&' only if not part of a legal entity sequence */
-	if (*s == '&' && !(xml_isentity(s))) {
-	    sub = "&amp;";
-	    len = 5;
-	}
-	/* '<' '>' are safe to substitute even if string is already UTF-8 coded
-	 * since UTF-8 strings won't contain '<' or '>' */
-	else if (*s == '<') {
-	    sub = "&lt;";
-	    len = 4;
-	}
-	else if (*s == '>') {
-	    sub = "&gt;";
-	    len = 4;
-	}
-	else if ((*s == '-') && notURL) {	/* can't be used in xml comment strings */
-	    sub = "&#45;";
-	    len = 5;
-	}
-	else if (*s == ' ' && prev && *prev == ' ' && notURL) {
-	    /* substitute 2nd and subsequent spaces with required_spaces */
-	    sub = "&#160;";  /* inkscape doesn't recognise &nbsp; */
-	    len = 6;
-	}
-	else if (*s == '"') {
-	    sub = "&quot;";
-	    len = 6;
-	}
-	else if (*s == '\'') {
-	    sub = "&#39;";
-	    len = 5;
-	}
-	else {
-	    sub = s;
-	    len = 1;
-	}
-	while (len--) {
-	    *p++ = *sub++;
-	    pos++;
-	}
-	prev = s;
-	s++;
-    }
-    *p = '\0';
-    return buf;
+// write a string to the given file, XML-escaping the input
+static inline int xml_puts(FILE *stream, const char *s) {
+  const xml_flags_t flags = {.dash = 1, .nbsp = 1};
+  return xml_escape(s, flags, put, stream);
 }
 
-static char *xml_string(char *s)
-{
-    return _xml_string(s,1);
-}
-
-static char *xml_url_string(char *s)
-{
-    return _xml_string(s,0);
+// wrapper around `xml_escape` to set flags for URL escaping
+static int xml_url_puts(FILE *f, const char *s) {
+  const xml_flags_t flags = {0};
+  return xml_escape(s, flags, put, f);
 }
 
 static int isGxlGrammar(char *name)
@@ -267,9 +192,9 @@ static void *idexists(Dt_t * ids, char *id)
  */
 static char *addid(Dt_t * ids, char *id)
 {
-    idv_t *idp = NEW(idv_t);
+    idv_t *idp = gv_alloc(sizeof(*idp));
 
-    idp->name = strdup(id);
+    idp->name = gv_strdup(id);
     dtinsert(ids, idp);
     return idp->name;
 }
@@ -321,19 +246,14 @@ static char *nodeID(gxlstate_t * stp, Agnode_t * n)
 static char *createEdgeId(gxlstate_t * stp, Agedge_t * e)
 {
     int edgeIdCounter = 1;
-    char buf[BUFSIZ];
     char *hname = nodeID(stp, AGHEAD(e));
     char *tname = nodeID(stp, AGTAIL(e));
-    int baselen = strlen(hname) + strlen(tname) + sizeof(EDGEOP);
-    int len = baselen + EXTRA;
-    char *bp;
+    size_t baselen = strlen(hname) + strlen(tname) + sizeof(EDGEOP);
+    size_t len = baselen + EXTRA;
     char *endp;			/* where to append ':' and number */
     char *rv;
 
-    if (len <= BUFSIZ)
-	bp = buf;
-    else
-	bp = N_NEW(len, char);
+    char *bp = gv_calloc(len, sizeof(bp[0]));
     endp = bp + (baselen - 1);
 
     sprintf(bp, "%s%s%s", tname, EDGEOP, hname);
@@ -342,8 +262,7 @@ static char *createEdgeId(gxlstate_t * stp, Agedge_t * e)
     }
 
     rv = addid(stp->idList, bp);
-    if (bp != buf)
-	free(bp);
+    free(bp);
     return rv;
 }
 
@@ -364,11 +283,15 @@ static void graphAttrs(FILE * gxlFile, Agraph_t * g)
 
     val = agget(g, GXL_ROLE);
     if (!EMPTY(val)) {
-	fprintf(gxlFile, " role=\"%s\"", xml_string(val));
+	fprintf(gxlFile, " role=\"");
+	xml_puts(gxlFile, val);
+	fprintf(gxlFile, "\"");
     }
     val = agget(g, GXL_HYPER);
     if (!EMPTY(val)) {
-	fprintf(gxlFile, " hypergraph=\"%s\"", xml_string(val));
+	fprintf(gxlFile, " hypergraph=\"");
+	xml_puts(gxlFile, val);
+	fprintf(gxlFile, "\"");
     }
 }
 
@@ -378,15 +301,21 @@ static void edgeAttrs(FILE * gxlFile, Agedge_t * e)
 
     val = agget(e, GXL_ID);
     if (!EMPTY(val)) {
-	fprintf(gxlFile, " id=\"%s\"", xml_string(val));
+	fprintf(gxlFile, " id=\"");
+	xml_puts(gxlFile, val);
+	fprintf(gxlFile, "\"");
     }
     val = agget(e, GXL_FROM);
     if (!EMPTY(val)) {
-	fprintf(gxlFile, " fromorder=\"%s\"", xml_string(val));
+	fprintf(gxlFile, " fromorder=\"");
+	xml_puts(gxlFile, val);
+	fprintf(gxlFile, "\"");
     }
     val = agget(e, GXL_TO);
     if (!EMPTY(val)) {
-	fprintf(gxlFile, " toorder=\"%s\"", xml_string(val));
+	fprintf(gxlFile, " toorder=\"");
+	xml_puts(gxlFile, val);
+	fprintf(gxlFile, "\"");
     }
 }
 
@@ -398,7 +327,9 @@ static void printHref(FILE * gxlFile, void *n)
     val = agget(n, GXL_TYPE);
     if (!EMPTY(val)) {
 	tabover(gxlFile);
-	fprintf(gxlFile, "\t<type xlink:href=\"%s\">\n", xml_url_string(val));
+	fprintf(gxlFile, "\t<type xlink:href=\"");
+	xml_url_puts(gxlFile, val);
+	fprintf(gxlFile, "\">\n");
 	tabover(gxlFile);
 	fprintf(gxlFile, "\t</type>\n");
     }
@@ -409,6 +340,8 @@ static void
 writeDict(Agraph_t * g, FILE * gxlFile, char *name, Dict_t * dict,
 	  int isGraph)
 {
+    (void)g;
+
     Dict_t *view;
     Agsym_t *sym, *psym;
 
@@ -430,25 +363,38 @@ writeDict(Agraph_t * g, FILE * gxlFile, char *name, Dict_t * dict,
 		locatorVal += 13;
 
 		tabover(gxlFile);
-		fprintf(gxlFile, "\t<attr name=\"%s\">\n", xml_string(sym->name));
+		fprintf(gxlFile, "\t<attr name=\"");
+		xml_puts(gxlFile, sym->name);
+		fprintf(gxlFile, "\">\n");
 		tabover(gxlFile);
-		fprintf(gxlFile, "\t\t<locator xlink:href=\"%s\"/>\n",
-			xml_url_string(locatorVal));
+		fprintf(gxlFile, "\t\t<locator xlink:href=\"");
+		xml_url_puts(gxlFile, locatorVal);
+		fprintf(gxlFile, "\"/>\n");
 		tabover(gxlFile);
 		fprintf(gxlFile, "\t</attr>\n");
 	    } else {
 		tabover(gxlFile);
 		if (isGraph) {
-		    fprintf(gxlFile, "\t<attr name=\"%s\" ", xml_string(sym->name));
-		    fprintf(gxlFile, "kind=\"%s\">\n", xml_string(name));
+		    fprintf(gxlFile, "\t<attr name=\"");
+		    xml_puts(gxlFile, sym->name);
+		    fprintf(gxlFile, "\" ");
+		    fprintf(gxlFile, "kind=\"");
+		    xml_puts(gxlFile, name);
+		    fprintf(gxlFile, "\">\n");
 		}
 		else {
-		    fprintf(gxlFile, "\t<attr name=\"%s:", xml_string(name));
-		    fprintf(gxlFile, "%s\" kind=\"", xml_string(sym->name));
-		    fprintf(gxlFile, "%s\">\n", xml_string(name));
+		    fprintf(gxlFile, "\t<attr name=\"");
+		    xml_puts(gxlFile, name);
+		    fprintf(gxlFile, ":");
+		    xml_puts(gxlFile, sym->name);
+		    fprintf(gxlFile, "\" kind=\"");
+		    xml_puts(gxlFile, name);
+		    fprintf(gxlFile, "\">\n");
 		}
 		tabover(gxlFile);
-		fprintf(gxlFile, "\t\t<string>%s</string>\n", xml_string(sym->defval));
+		fprintf(gxlFile, "\t\t<string>");
+		xml_puts(gxlFile, sym->defval);
+		fprintf(gxlFile, "</string>\n");
 		tabover(gxlFile);
 		fprintf(gxlFile, "\t</attr>\n");
 	    }
@@ -464,10 +410,16 @@ writeDict(Agraph_t * g, FILE * gxlFile, char *name, Dict_t * dict,
 		}
 
 		tabover(gxlFile);
-		fprintf(gxlFile, "\t<attr name=\"%s\" ", xml_string(((sym->name) + GXL_COMP_LEN)));
-		fprintf(gxlFile, "kind=\"%s\">\n", xml_string(name));
+		fprintf(gxlFile, "\t<attr name=\"");
+		xml_puts(gxlFile, sym->name + GXL_COMP_LEN);
+		fprintf(gxlFile, "\" ");
+		fprintf(gxlFile, "kind=\"");
+		xml_puts(gxlFile, name);
+		fprintf(gxlFile, "\">\n");
 		tabover(gxlFile);
-		fprintf(gxlFile, "\t\t%s\n", xml_string(sym->defval));
+		fprintf(gxlFile, "\t\t");
+		xml_puts(gxlFile, sym->defval);
+		fprintf(gxlFile, "\n");
 		tabover(gxlFile);
 		fprintf(gxlFile, "\t</attr>\n");
 	    }
@@ -479,7 +431,7 @@ writeDict(Agraph_t * g, FILE * gxlFile, char *name, Dict_t * dict,
 static void writeDicts(Agraph_t * g, FILE * gxlFile)
 {
     Agdatadict_t *def;
-    if ((def = (Agdatadict_t *) agdatadict(g, FALSE))) {
+    if ((def = agdatadict(g, FALSE))) {
 	writeDict(g, gxlFile, "graph", def->dict.g, 1);
 	writeDict(g, gxlFile, "node", def->dict.n, 0);
 	writeDict(g, gxlFile, "edge", def->dict.e, 0);
@@ -492,10 +444,7 @@ writeHdr(gxlstate_t * stp, Agraph_t * g, FILE * gxlFile, int top)
     char *name;
     char *kind;
     char *uniqueName;
-    char buf[BUFSIZ];
-    char *bp;
-    char *dynbuf = 0;
-    int len;
+    size_t len;
 
     Level++;
     stp->attrsNotWritten = AGATTRWF(g);
@@ -509,11 +458,7 @@ writeHdr(gxlstate_t * stp, Agraph_t * g, FILE * gxlFile, int top)
 	/* this must be anonymous graph */
 
 	len = strlen(name) + sizeof("N_");
-	if (len <= BUFSIZ)
-	    bp = buf;
-	else {
-	    bp = dynbuf = N_NEW(len, char);
-	}
+	char *bp = gv_calloc(len, sizeof(bp[0]));
 	sprintf(bp, "N_%s", name);
 	if (idexists(stp->idList, bp) || !legalGXLName(bp)) {
 	    bp = createNodeId(stp->idList);
@@ -524,7 +469,7 @@ writeHdr(gxlstate_t * stp, Agraph_t * g, FILE * gxlFile, int top)
 
 	tabover(gxlFile);
 	fprintf(gxlFile, "<node id=\"%s\">\n", bp);
-	free(dynbuf);
+	free(bp);
 	Level++;
     } else {
 	Tailport = agattr(g, AGEDGE, "tailport", NULL);
@@ -543,7 +488,9 @@ writeHdr(gxlstate_t * stp, Agraph_t * g, FILE * gxlFile, int top)
 	tabover(gxlFile);
 	fprintf(gxlFile, "\t<attr name=\"name\">\n");
 	tabover(gxlFile);
-	fprintf(gxlFile, "\t\t<string>%s</string>\n", xml_string(name));
+	fprintf(gxlFile, "\t\t<string>");
+	xml_puts(gxlFile, name);
+	fprintf(gxlFile, "</string>\n");
 	tabover(gxlFile);
 	fprintf(gxlFile, "\t</attr>\n");
     }
@@ -586,7 +533,7 @@ static void writeSubgs(gxlstate_t * stp, Agraph_t * g, FILE * gxlFile)
     }
 }
 
-static int writeEdgeName(Agedge_t * e, FILE * gxlFile, int terminate)
+static int writeEdgeName(Agedge_t * e, FILE * gxlFile)
 {
     int rv;
     char *p;
@@ -596,7 +543,9 @@ static int writeEdgeName(Agedge_t * e, FILE * gxlFile, int terminate)
 	tabover(gxlFile);
 	fprintf(gxlFile, "\t<attr name=\"key\">\n");
 	tabover(gxlFile);
-	fprintf(gxlFile, "\t\t<string>%s</string>\n", xml_string(p));
+	fprintf(gxlFile, "\t\t<string>");
+	xml_puts(gxlFile, p);
+	fprintf(gxlFile, "</string>\n");
 	tabover(gxlFile);
 	fprintf(gxlFile, "\t</attr>\n");
 	rv = TRUE;
@@ -609,15 +558,14 @@ static int writeEdgeName(Agedge_t * e, FILE * gxlFile, int terminate)
 static void
 writeNondefaultAttr(void *obj, FILE * gxlFile, Dict_t * defdict)
 {
-    Agattr_t *data;
     Agsym_t *sym;
     int cnt = 0;
 
     if ((AGTYPE(obj) == AGINEDGE) || (AGTYPE(obj) == AGOUTEDGE)) {
-	if (writeEdgeName(obj, gxlFile, FALSE))
+	if (writeEdgeName(obj, gxlFile))
 	    cnt++;
     }
-    data = (Agattr_t *) agattrrec(obj);
+    Agattr_t *data = agattrrec(obj);
     if (data) {
 	for (sym = dtfirst(defdict); sym; sym = dtnext(defdict, sym)) {
 	    if (!isGxlGrammar(sym->name)) {
@@ -639,24 +587,29 @@ writeNondefaultAttr(void *obj, FILE * gxlFile, Dict_t * defdict)
 			locatorVal += 13;
 
 			tabover(gxlFile);
-			fprintf(gxlFile, "\t<attr name=\"%s\">\n",
-				xml_string(sym->name));
+			fprintf(gxlFile, "\t<attr name=\"");
+			xml_puts(gxlFile, sym->name);
+			fprintf(gxlFile, "\">\n");
 			tabover(gxlFile);
-			fprintf(gxlFile,
-				"\t\t<locator xlink:href=\"%s\"/>\n",
-				xml_url_string(locatorVal));
+			fprintf(gxlFile, "\t\t<locator xlink:href=\"");
+			xml_url_puts(gxlFile, locatorVal);
+			fprintf(gxlFile, "\"/>\n");
 			tabover(gxlFile);
 			fprintf(gxlFile, "\t</attr>\n");
 		    } else {
 			tabover(gxlFile);
-			fprintf(gxlFile, "\t<attr name=\"%s\"", xml_string(sym->name));
+			fprintf(gxlFile, "\t<attr name=\"");
+			xml_puts(gxlFile, sym->name);
+			fprintf(gxlFile, "\"");
 			if (aghtmlstr(data->str[sym->id])) {
 			  // This is a <…> string. Note this in the kind.
 			  fprintf(gxlFile, " kind=\"HTML-like string\"");
 			}
 			fprintf(gxlFile, ">\n");
 			tabover(gxlFile);
-			fprintf(gxlFile, "\t\t<string>%s</string>\n", xml_string(data->str[sym->id]));
+			fprintf(gxlFile, "\t\t<string>");
+			xml_puts(gxlFile, data->str[sym->id]);
+			fprintf(gxlFile, "</string>\n");
 			tabover(gxlFile);
 			fprintf(gxlFile, "\t</attr>\n");
 		    }
@@ -667,10 +620,13 @@ writeNondefaultAttr(void *obj, FILE * gxlFile, Dict_t * defdict)
 		    if (data->str[sym->id] != sym->defval) {
 
 			tabover(gxlFile);
-			fprintf(gxlFile, "\t<attr name=\"%s\">\n",
-				xml_string(((sym->name) + GXL_COMP_LEN)));
+			fprintf(gxlFile, "\t<attr name=\"");
+			xml_puts(gxlFile, sym->name + GXL_COMP_LEN);
+			fprintf(gxlFile, "\">\n");
 			tabover(gxlFile);
-			fprintf(gxlFile, "\t\t%s\n", xml_string(data->str[sym->id]));
+			fprintf(gxlFile, "\t\t");
+			xml_puts(gxlFile, data->str[sym->id]);
+			fprintf(gxlFile, "\n");
 			tabover(gxlFile);
 			fprintf(gxlFile, "\t</attr>\n");
 		    }
@@ -678,7 +634,7 @@ writeNondefaultAttr(void *obj, FILE * gxlFile, Dict_t * defdict)
 	    }
 	}
     }
-    AGATTRWF((Agobj_t *) obj) = !(AGATTRWF((Agobj_t *) obj));
+    AGATTRWF(obj) = !(AGATTRWF(obj));
 }
 
 /* nodeID:
@@ -686,7 +642,7 @@ writeNondefaultAttr(void *obj, FILE * gxlFile, Dict_t * defdict)
  */
 static int attrs_written(gxlstate_t * stp, void *obj)
 {
-    return !(AGATTRWF((Agobj_t *) obj) == stp->attrsNotWritten);
+    return !(AGATTRWF(obj) == stp->attrsNotWritten);
 }
 
 static void
@@ -706,7 +662,9 @@ writeNode(gxlstate_t * stp, Agnode_t * n, FILE * gxlFile, Dict_t * d)
 	tabover(gxlFile);
 	fprintf(gxlFile, "\t<attr name=\"name\">\n");
 	tabover(gxlFile);
-	fprintf(gxlFile, "\t\t<string>%s</string>\n", xml_string(name));
+	fprintf(gxlFile, "\t\t<string>");
+	xml_puts(gxlFile, name);
+	fprintf(gxlFile, "</string>\n");
 	tabover(gxlFile);
 	fprintf(gxlFile, "\t</attr>\n");
     }
@@ -725,9 +683,13 @@ static void writePort(Agedge_t * e, FILE * gxlFile, char *name)
     val = agget(e, name);
     if (val && val[0]) {
 	tabover(gxlFile);
-	fprintf(gxlFile, "\t<attr name=\"%s\">\n", xml_string(name));
+	fprintf(gxlFile, "\t<attr name=\"");
+	xml_puts(gxlFile, name);
+	fprintf(gxlFile, "\">\n");
 	tabover(gxlFile);
-	fprintf(gxlFile, "\t\t<string>%s</string>\n", xml_string(val));
+	fprintf(gxlFile, "\t\t<string>");
+	xml_puts(gxlFile, val);
+	fprintf(gxlFile, "</string>\n");
 	tabover(gxlFile);
 	fprintf(gxlFile, "\t</attr>\n");
     }
@@ -782,24 +744,23 @@ writeEdge(gxlstate_t * stp, Agedge_t * e, FILE * gxlFile, Dict_t * d)
     if (!(attrs_written(stp, e)))
 	writeNondefaultAttr(e, gxlFile, d);
     else
-	writeEdgeName(e, gxlFile, TRUE);
+	writeEdgeName(e, gxlFile);
     tabover(gxlFile);
     fprintf(gxlFile, "</edge>\n");
     Level--;
 }
 
 
-#define writeval(n) (((Agnodeinfo_t*)((n)->base.data))->written)
+#define writeval(n) (((Local_Agnodeinfo_t*)((n)->base.data))->written)
 
 static void writeBody(gxlstate_t * stp, Agraph_t * g, FILE * gxlFile)
 {
     Agnode_t *n;
     Agnode_t *realn;
     Agedge_t *e;
-    Agdatadict_t *dd;
 
     writeSubgs(stp, g, gxlFile);
-    dd = (Agdatadict_t *) agdatadict(g, FALSE);
+    Agdatadict_t *dd = agdatadict(g, FALSE);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	realn = agidnode(stp->root, AGID(n), 0);
 	if (!writeval(realn)) {
@@ -873,43 +834,40 @@ static void iterateBody(gxlstate_t * stp, Agraph_t * g)
     }
 }
 
-static gxlstate_t *initState(Agraph_t * g)
-{
-    gxlstate_t *stp = NEW(gxlstate_t);
-    stp->nodeMap = dtopen(&nameDisc, Dtoset);
-    stp->graphMap = dtopen(&nameDisc, Dtoset);
-    stp->synNodeMap = dtopen(&nameDisc, Dtoset);
-    stp->idList = dtopen(&idDisc, Dtoset);
-    stp->attrsNotWritten = 0;
-    stp->root = g;
-    stp->directed = agisdirected(g);
-    return stp;
+static gxlstate_t initState(Agraph_t *g) {
+  gxlstate_t stp = {0};
+  stp.nodeMap = dtopen(&nameDisc, Dtoset);
+  stp.graphMap = dtopen(&nameDisc, Dtoset);
+  stp.synNodeMap = dtopen(&nameDisc, Dtoset);
+  stp.idList = dtopen(&idDisc, Dtoset);
+  stp.attrsNotWritten = 0;
+  stp.root = g;
+  stp.directed = agisdirected(g) != 0;
+  return stp;
 }
 
-static void freeState(gxlstate_t * stp)
-{
-    dtclose(stp->nodeMap);
-    dtclose(stp->graphMap);
-    dtclose(stp->synNodeMap);
-    dtclose(stp->idList);
-    free(stp);
+static void freeState(gxlstate_t stp) {
+  dtclose(stp.nodeMap);
+  dtclose(stp.graphMap);
+  dtclose(stp.synNodeMap);
+  dtclose(stp.idList);
 }
 
 void gv_to_gxl(Agraph_t * g, FILE * gxlFile)
 {
-    gxlstate_t *stp = initState(g);
-    aginit(g, AGNODE, "node", sizeof(Agnodeinfo_t), TRUE);
+    gxlstate_t stp = initState(g);
+    aginit(g, AGNODE, "node", sizeof(Local_Agnodeinfo_t), TRUE);
 
-    iterateHdr(stp, g);
-    iterateBody(stp, g);
+    iterateHdr(&stp, g);
+    iterateBody(&stp, g);
 
     Level = 0;
 
     fprintf(gxlFile, "<?xml version=\"1.0\" encoding=\"iso-8859-1\"?>\n");
     fprintf(gxlFile, "<gxl>\n");
 
-    writeHdr(stp, g, gxlFile, TRUE);
-    writeBody(stp, g, gxlFile);
+    writeHdr(&stp, g, gxlFile, TRUE);
+    writeBody(&stp, g, gxlFile);
     writeTrl(g, gxlFile, TRUE);
 
     fprintf(gxlFile, "</gxl>\n");
