@@ -11,6 +11,7 @@
 #include	<cgraph/cghdr.h>
 #include	<cgraph/unreachable.h>
 #include	<stddef.h>
+#include	<stdbool.h>
 
 /*
  * dynamic attributes
@@ -77,8 +78,8 @@ static Dict_t *agdictof(Agraph_t * g, int kind)
     return dict;
 }
 
-static Agsym_t *agnewsym(Agraph_t * g, char *name, char *value, int id, int kind)
-{
+static Agsym_t *agnewsym(Agraph_t * g, const char *name, const char *value,
+                         int id, int kind) {
     Agsym_t *sym;
     sym = agalloc(g, sizeof(Agsym_t));
     sym->kind = (unsigned char) kind;
@@ -106,7 +107,7 @@ static Agdatadict_t *agmakedatadict(Agraph_t * g)
     Agraph_t *par;
     Agdatadict_t *parent_dd, *dd;
 
-    dd = agbindrec(g, DataDictName, sizeof(Agdatadict_t), FALSE);
+    dd = agbindrec(g, DataDictName, sizeof(Agdatadict_t), false);
     dd->dict.n = agdtopen(g, &AgDataDictDisc, Dttree);
     dd->dict.e = agdtopen(g, &AgDataDictDisc, Dttree);
     dd->dict.g = agdtopen(g, &AgDataDictDisc, Dttree);
@@ -153,11 +154,10 @@ Agsym_t *agattrsym(void *obj, char *name)
 {
     Agattr_t *data;
     Agsym_t *rv;
-    char *arg = name;
 
     data = agattrrec(obj);
     if (data)
-	rv = agdictsym(data->dict, arg);
+	rv = agdictsym(data->dict, name);
     else
 	rv = NULL;
     return rv;
@@ -183,7 +183,7 @@ static Agrec_t *agmakeattrs(Agraph_t * context, void *obj)
     Agsym_t *sym;
     Dict_t *datadict;
 
-    rec = agbindrec(obj, AgDataRecName, sizeof(Agattr_t), FALSE);
+    rec = agbindrec(obj, AgDataRecName, sizeof(Agattr_t), false);
     datadict = agdictof(context, AGTYPE(obj));
     assert(datadict);
     if (rec->dict == NULL) {
@@ -218,9 +218,9 @@ static void freesym(Dict_t * d, void * obj, Dtdisc_t * disc)
 {
     Agsym_t *sym;
 
-    NOTUSED(d);
+    (void)d;
     sym = obj;
-    NOTUSED(disc);
+    (void)disc;
     agstrfree(Ag_G_global, sym->name);
     agstrfree(Ag_G_global, sym->defval);
     agfree(Ag_G_global, sym);
@@ -234,9 +234,7 @@ Agattr_t *agattrrec(void *obj)
 
 static void addattr(Agraph_t * g, Agobj_t * obj, Agsym_t * sym)
 {
-    Agattr_t *attr;
-
-    attr = (Agattr_t *) agattrrec(obj);
+    Agattr_t *attr = agattrrec(obj);
     assert(attr != NULL);
     if (sym->id >= MINATTR)
 	attr->str = (char **) AGDISC(g, mem)->resize(AGCLOS(g, mem),
@@ -248,9 +246,37 @@ static void addattr(Agraph_t * g, Agobj_t * obj, Agsym_t * sym)
     attr->str[sym->id] = agstrdup(g, sym->defval);
 }
 
+static Agsym_t *getattr(Agraph_t *g, int kind, char *name) {
+  Agsym_t *rv = 0;
+  Dict_t *dict;
+  dict = agdictof(g, kind);
+  if (dict) {
+    rv = agdictsym(dict, name); // viewpath up to root
+  }
+  return rv;
+}
 
-static Agsym_t *setattr(Agraph_t * g, int kind, char *name, char *value)
-{
+static void unviewsubgraphsattr(Agraph_t *parent, char *name) {
+  Agraph_t *subg;
+  Agsym_t *psym, *lsym;
+  Dict_t *ldict;
+
+  psym = getattr(parent, AGRAPH, name);
+  if (!psym) {
+    return; // supposedly can't happen, see setattr()
+  }
+  for (subg = agfstsubg(parent); subg; subg = agnxtsubg(subg)) {
+    ldict = agdatadict(subg, TRUE)->dict.g;
+    lsym = aglocaldictsym(ldict, name);
+    if (lsym) {
+      continue;
+    }
+    lsym = agnewsym(agroot(subg), name, agxget(subg, psym), psym->id, AGRAPH);
+    dtinsert(ldict, lsym);
+  }
+}
+
+static Agsym_t *setattr(Agraph_t * g, int kind, char *name, const char *value) {
     Dict_t *ldict, *rdict;
     Agsym_t *lsym, *psym, *rsym, *rv;
     Agraph_t *root;
@@ -263,6 +289,11 @@ static Agsym_t *setattr(Agraph_t * g, int kind, char *name, char *value)
     ldict = agdictof(g, kind);
     lsym = aglocaldictsym(ldict, name);
     if (lsym) {			/* update old local definition */
+	if (g != root && streq(name, "layout"))
+	    agerr(AGWARN, "layout attribute is invalid except on the root graph\n");
+        if (kind == AGRAPH) {
+	    unviewsubgraphsattr(g,name);
+        }
 	agstrfree(g, lsym->defval);
 	lsym->defval = agstrdup(g, value);
 	rv = lsym;
@@ -297,19 +328,9 @@ static Agsym_t *setattr(Agraph_t * g, int kind, char *name, char *value)
 	    rv = rsym;
 	}
     }
-    if (rv && (kind == AGRAPH))
+    if (rv && kind == AGRAPH)
 	agxset(g, rv, value);
-    agmethod_upd(g, g, rv);	/* JCE and GN wanted this */
-    return rv;
-}
-
-static Agsym_t *getattr(Agraph_t * g, int kind, char *name)
-{
-    Agsym_t *rv = 0;
-    Dict_t *dict;
-    dict = agdictof(g, kind);
-    if (dict)
-	rv = agdictsym(dict, name);	/* viewpath up to root */
+    agmethod_upd(g, g, rv);
     return rv;
 }
 
@@ -319,8 +340,7 @@ static Agsym_t *getattr(Agraph_t * g, int kind, char *name)
  * when a new attribute is created, existing graphs/nodes/edges
  * receive its default value.
  */
-Agsym_t *agattr(Agraph_t * g, int kind, char *name, char *value)
-{
+Agsym_t *agattr(Agraph_t * g, int kind, char *name, const char *value) {
     Agsym_t *rv;
 
     if (g == 0) {
@@ -432,7 +452,7 @@ char *agget(void *obj, char *name)
 	rv = 0;			/* note was "", but this provides more info */
     else {
 	data = agattrrec(obj);
-	rv = (char *) data->str[sym->id];
+	rv = data->str[sym->id];
     }
     return rv;
 }
@@ -444,12 +464,11 @@ char *agxget(void *obj, Agsym_t * sym)
 
     data = agattrrec(obj);
     assert(sym->id >= 0 && sym->id < topdictsize(obj));
-    rv = (char *) (data->str[sym->id]);
+    rv = data->str[sym->id];
     return rv;
 }
 
-int agset(void *obj, char *name, char *value)
-{
+int agset(void *obj, char *name, const char *value) {
     Agsym_t *sym;
     int rv;
 
@@ -461,7 +480,7 @@ int agset(void *obj, char *name, char *value)
     return rv;
 }
 
-int agxset(void *obj, Agsym_t * sym, char *value)
+int agxset(void *obj, Agsym_t * sym, const char *value)
 {
     Agraph_t *g;
     Agobj_t *hdr;
@@ -490,8 +509,7 @@ int agxset(void *obj, Agsym_t * sym, char *value)
     return SUCCESS;
 }
 
-int agsafeset(void *obj, char *name, char *value, char *def)
-{
+int agsafeset(void *obj, char *name, const char *value, const char *def) {
     Agsym_t *a;
 
     a = agattr(agraphof(obj), AGTYPE(obj), name, 0);
@@ -500,6 +518,13 @@ int agsafeset(void *obj, char *name, char *value, char *def)
     return agxset(obj, a, value);
 }
 
+static void agraphattr_init_wrapper(Agraph_t *g, Agobj_t *ignored1,
+                                    void *ignored2) {
+  (void)ignored1;
+  (void)ignored2;
+
+  agraphattr_init(g);
+}
 
 /*
  * attach attributes to the already created graph objs.
@@ -513,8 +538,7 @@ static void init_all_attrs(Agraph_t * g)
     Agedge_t *e;
 
     root = agroot(g);
-    agapply(root, (Agobj_t *) root, (agobjfn_t) agraphattr_init,
-	    NULL, TRUE);
+    agapply(root, (Agobj_t*)root, agraphattr_init_wrapper, NULL, TRUE);
     for (n = agfstnode(root); n; n = agnxtnode(root, n)) {
 	agnodeattr_init(g, n);
 	for (e = agfstout(root, n); e; e = agnxtout(root, e)) {
