@@ -73,6 +73,8 @@
 #define		DEFAULT_NODEWIDTH	0.75
 #define		MIN_NODEWIDTH		0.01
 #define		DEFAULT_NODESHAPE	"ellipse"
+#define		DEFAULT_NODEPENWIDTH	1.0
+#define		MIN_NODEPENWIDTH	0.0
 
 #define		NODENAME_ESC		"\\N"
 
@@ -126,7 +128,6 @@
 #define		CLST    3
 
 /* output languages */
-#define		HPGL		2	/* HP Graphics Language */
 #define		PCL		3	/* Printer Control Language */
 #define		MIF		4	/* Adobe FrameMaker */
 #define		PIC_format	5	/* symbol PIC is used by compilers for 
@@ -162,10 +163,6 @@
 #define SELFEDGE    8
 #define EDGETYPEMASK	 15	/* the OR of the above */
 
-/* for graph server */
-#define		SERVER_NN	200
-#define		SERVER_NE	500
-
 /* for neato */
 #define Spring_coeff    1.0
 #define MYHUGE          (1.0e+37)
@@ -257,18 +254,18 @@
 
 /* Flags stored in GD_flags 
  * Bit(s):  0     unused
- *          1-3   ET_ 
+ *          1-3   EDGETYPE_
  *          4     NEW_RANK
  */
 
 /* edge types */
-#define ET_NONE 	(0 << 1)
-#define ET_LINE 	(1 << 1)
-#define ET_CURVED 	(2 << 1)
-#define ET_PLINE 	(3 << 1)
-#define ET_ORTHO 	(4 << 1)
-#define ET_SPLINE 	(5 << 1)
-#define ET_COMPOUND 	(6 << 1)
+#define EDGETYPE_NONE       (0 << 1)
+#define EDGETYPE_LINE       (1 << 1)
+#define EDGETYPE_CURVED     (2 << 1)
+#define EDGETYPE_PLINE      (3 << 1)
+#define EDGETYPE_ORTHO      (4 << 1)
+#define EDGETYPE_SPLINE     (5 << 1)
+#define EDGETYPE_COMPOUND   (6 << 1)
 
 /* New ranking is used */
 #define NEW_RANK    	(1 << 4)
