@@ -15,6 +15,7 @@
 #include <cgraph/tokenize.h>
 #include <common/htmltable.h>
 #include <common/entities.h>
+#include <limits.h>
 #include <math.h>
 #include <gvc/gvc.h>
 #include <cgraph/strcasecmp.h>
@@ -29,11 +30,11 @@
  */
 nodequeue *new_queue(int sz)
 {
-    nodequeue *q = NEW(nodequeue);
+    nodequeue *q = gv_alloc(sizeof(nodequeue));
 
     if (sz <= 1)
 	sz = 2;
-    q->head = q->tail = q->store = N_NEW(sz, node_t *);
+    q->head = q->tail = q->store = gv_calloc((size_t)sz, sizeof(node_t*));
     q->limit = q->store + sz;
     return q;
 }
@@ -46,7 +47,7 @@ void free_queue(nodequeue * q)
 
 void enqueue(nodequeue * q, node_t * n)
 {
-    *(q->tail++) = n;
+    *q->tail++ = n;
     if (q->tail >= q->limit)
 	q->tail = q->store;
 }
@@ -57,43 +58,41 @@ node_t *dequeue(nodequeue * q)
     if (q->head == q->tail)
 	n = NULL;
     else {
-	n = *(q->head++);
+	n = *q->head++;
 	if (q->head >= q->limit)
 	    q->head = q->store;
     }
     return n;
 }
 
-int late_int(void *obj, attrsym_t * attr, int def, int low)
-{
-    char *p;
-    char *endp;
-    int rv;
+int late_int(void *obj, attrsym_t *attr, int defaultValue, int minimum) {
     if (attr == NULL)
-	return def;
-    p = ag_xget(obj, attr);
+        return defaultValue;
+    char *p = ag_xget(obj, attr);
     if (!p || p[0] == '\0')
-	return def;
-    rv = strtol (p, &endp, 10);
-    if (p == endp) return def;  /* invalid int format */
-    if (rv < low) return low;
-    else return rv;
+        return defaultValue;
+    char *endp;
+    long rv = strtol(p, &endp, 10);
+    if (p == endp || rv > INT_MAX)
+        return defaultValue; /* invalid int format */
+    if (rv < minimum)
+        return minimum;
+    else return (int)rv;
 }
 
-double late_double(void *obj, attrsym_t * attr, double def, double low)
-{
-    char *p;
-    char *endp;
-    double rv;
-
+double late_double(void *obj, attrsym_t *attr, double defaultValue,
+                   double minimum) {
     if (!attr || !obj)
-	return def;
-    p = ag_xget(obj, attr);
+        return defaultValue;
+    char *p = ag_xget(obj, attr);
     if (!p || p[0] == '\0')
-	return def;
-    rv = strtod (p, &endp);
-    if (p == endp) return def;  /* invalid double format */
-    if (rv < low) return low;
+        return defaultValue;
+    char *endp;
+    double rv = strtod(p, &endp);
+    if (p == endp)
+        return defaultValue; /* invalid double format */
+    if (rv < minimum)
+        return minimum;
     else return rv;
 }
 
@@ -105,35 +104,29 @@ double late_double(void *obj, attrsym_t * attr, double def, double low)
  * If the value is 0, we return the default. Otherwise, we return the value.
  * Set but negative values are treated like 0.
  */
-double get_inputscale (graph_t* g)
-{
-    double d;
-
+double get_inputscale(graph_t *g) {
     if (PSinputscale > 0) return PSinputscale;  /* command line flag prevails */
-    d = late_double(g, agfindgraphattr(g, "inputscale"), -1, 0);
+    double d = late_double(g, agfindgraphattr(g, "inputscale"), -1, 0);
     if (d == 0) return POINTS_PER_INCH;
     else return d;
 }
 
-char *late_string(void *obj, attrsym_t * attr, char *def)
-{
+char *late_string(void *obj, attrsym_t *attr, char *defaultValue) {
     if (!attr || !obj)
-	return def;
+        return defaultValue;
     return agxget(obj, attr);
 }
 
-char *late_nnstring(void *obj, attrsym_t * attr, char *def)
-{
-    char *rv = late_string(obj, attr, def);
+char *late_nnstring(void *obj, attrsym_t *attr, char *defaultValue) {
+    char *rv = late_string(obj, attr, defaultValue);
     if (!rv || (rv[0] == '\0'))
-	rv = def;
+        return defaultValue;
     return rv;
 }
 
-bool late_bool(void *obj, attrsym_t * attr, bool def)
-{
+bool late_bool(void *obj, attrsym_t *attr, bool defaultValue) {
     if (attr == NULL)
-	return def;
+        return defaultValue;
 
     return mapbool(agxget(obj, attr));
 }
@@ -141,7 +134,7 @@ bool late_bool(void *obj, attrsym_t * attr, bool def)
 /* union-find */
 node_t *UF_find(node_t * n)
 {
-    while (ND_UF_parent(n) && (ND_UF_parent(n) != n)) {
+    while (ND_UF_parent(n) && ND_UF_parent(n) != n) {
 	if (ND_UF_parent(ND_UF_parent(n)))
 	    ND_UF_parent(n) = ND_UF_parent(ND_UF_parent(n));
 	n = ND_UF_parent(n);
@@ -237,7 +230,7 @@ pointf Bezier(pointf * V, int degree, double t, pointf * Left, pointf * Right)
 	for (j = 0; j <= degree; j++)
 	    Right[j] = Vtemp[degree - j][j];
 
-    return (Vtemp[degree][0]);
+    return Vtemp[degree][0];
 }
 
 #ifdef DEBUG
@@ -372,27 +365,25 @@ const char *safefile(const char *filename)
 	    dirs = mkDirlist (pathlist, &maxdirlen);
     }
 
-    if ((*filename == DIRSEP[0]) || !dirs)
+    if (*filename == DIRSEP[0] || !dirs)
 	return filename;
 
     return findPath (dirs, maxdirlen, filename);
 }
 
-int maptoken(char *p, char **name, int *val)
-{
-    int i;
+int maptoken(char *p, char **name, int *val) {
     char *q;
 
-    for (i = 0; (q = name[i]) != 0; i++)
-	if (p && streq(p, q))
-	    break;
+    int i = 0;
+    for (; (q = name[i]) != 0; i++)
+        if (p && streq(p, q))
+            break;
     return val[i];
 }
 
-bool mapBool(const char *p, bool dflt)
-{
+bool mapBool(const char *p, bool defaultValue) {
     if (!p || *p == '\0')
-	return dflt;
+        return defaultValue;
     if (!strcasecmp(p, "false"))
 	return false;
     if (!strcasecmp(p, "no"))
@@ -404,7 +395,7 @@ bool mapBool(const char *p, bool dflt)
     if (isdigit((int)*p))
 	return atoi(p) != 0;
     else
-	return dflt;
+        return defaultValue;
 }
 
 bool mapbool(const char *p)
@@ -430,7 +421,7 @@ pointf dotneato_closest(splines * spl, pointf pt)
 	    b.x = bz.list[j].x;
 	    b.y = bz.list[j].y;
 	    d2 = DIST2(b, pt);
-	    if ((bestj == -1) || (d2 < bestdist2)) {
+	    if (bestj == -1 || d2 < bestdist2) {
 		besti = i;
 		bestj = j;
 		bestdist2 = d2;
@@ -494,9 +485,9 @@ pointf spline_at_y(splines * spl, double y)
     else {
 	for (i = 0; i < bz.size; i += 3) {
 	    for (j = 0; j < 3; j++) {
-		if ((bz.list[i + j].y <= y) && (y <= bz.list[i + j + 1].y))
+		if (bz.list[i + j].y <= y && y <= bz.list[i + j + 1].y)
 		    break;
-		if ((bz.list[i + j].y >= y) && (y >= bz.list[i + j + 1].y))
+		if (bz.list[i + j].y >= y && y >= bz.list[i + j + 1].y)
 		    break;
 	    }
 	    if (j < 3)
@@ -507,7 +498,7 @@ pointf spline_at_y(splines * spl, double y)
 	    c[j].x = bz.list[i + j].x;
 	    c[j].y = bz.list[i + j].y;
 	    /* make the spline be monotonic in Y, awful but it works for now */
-	    if ((j > 0) && (c[j].y > c[j - 1].y))
+	    if (j > 0 && c[j].y > c[j - 1].y)
 		c[j].y = c[j - 1].y;
 	}
 	low = 0.0;
@@ -531,6 +522,7 @@ pointf spline_at_y(splines * spl, double y)
 static int Tflag;
 void gvToggle(int s)
 {
+    (void)s;
     Tflag = !Tflag;
 #if !defined(_WIN32)
     signal(SIGUSR1, gvToggle);
@@ -563,10 +555,10 @@ void common_init_node(node_t * n)
     fi.fontname = late_nnstring(n, N_fontname, DEFAULT_FONTNAME);
     fi.fontcolor = late_nnstring(n, N_fontcolor, DEFAULT_COLOR);
     ND_label(n) = make_label(n, str,
-	        ((aghtmlstr(str) ? LT_HTML : LT_NONE) | ( (shapeOf(n) == SH_RECORD) ? LT_RECD : LT_NONE)),
+	        (aghtmlstr(str) ? LT_HTML : LT_NONE) | ( (shapeOf(n) == SH_RECORD) ? LT_RECD : LT_NONE),
 		fi.fontsize, fi.fontname, fi.fontcolor);
-    if (N_xlabel && (str = agxget(n, N_xlabel)) && (str[0])) {
-	ND_xlabel(n) = make_label(n, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+    if (N_xlabel && (str = agxget(n, N_xlabel)) && str[0]) {
+	ND_xlabel(n) = make_label(n, str, aghtmlstr(str) ? LT_HTML : LT_NONE,
 				fi.fontsize, fi.fontname, fi.fontcolor);
 	GD_has_labels(agraphof(n)) |= NODE_XLABEL;
     }
@@ -643,36 +635,36 @@ int common_init_edge(edge_t * e)
 
     fi.fontname = NULL;
     lfi.fontname = NULL;
-    if (E_label && (str = agxget(e, E_label)) && (str[0])) {
+    if (E_label && (str = agxget(e, E_label)) && str[0]) {
 	r = 1;
 	initFontEdgeAttr(e, &fi);
-	ED_label(e) = make_label(e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	ED_label(e) = make_label(e, str, aghtmlstr(str) ? LT_HTML : LT_NONE,
 				fi.fontsize, fi.fontname, fi.fontcolor);
 	GD_has_labels(sg) |= EDGE_LABEL;
 	ED_label_ontop(e) =
 	    mapbool(late_string(e, E_label_float, "false")) ? TRUE : FALSE;
     }
 
-    if (E_xlabel && (str = agxget(e, E_xlabel)) && (str[0])) {
+    if (E_xlabel && (str = agxget(e, E_xlabel)) && str[0]) {
 	if (!fi.fontname)
 	    initFontEdgeAttr(e, &fi);
-	ED_xlabel(e) = make_label(e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	ED_xlabel(e) = make_label(e, str, aghtmlstr(str) ? LT_HTML : LT_NONE,
 				fi.fontsize, fi.fontname, fi.fontcolor);
 	GD_has_labels(sg) |= EDGE_XLABEL;
     }
 
 
     /* vladimir */
-    if (E_headlabel && (str = agxget(e, E_headlabel)) && (str[0])) {
+    if (E_headlabel && (str = agxget(e, E_headlabel)) && str[0]) {
 	initFontLabelEdgeAttr(e, &fi, &lfi);
-	ED_head_label(e) = make_label(e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	ED_head_label(e) = make_label(e, str, aghtmlstr(str) ? LT_HTML : LT_NONE,
 				lfi.fontsize, lfi.fontname, lfi.fontcolor);
 	GD_has_labels(sg) |= HEAD_LABEL;
     }
-    if (E_taillabel && (str = agxget(e, E_taillabel)) && (str[0])) {
+    if (E_taillabel && (str = agxget(e, E_taillabel)) && str[0]) {
 	if (!lfi.fontname)
 	    initFontLabelEdgeAttr(e, &fi, &lfi);
-	ED_tail_label(e) = make_label(e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	ED_tail_label(e) = make_label(e, str, aghtmlstr(str) ? LT_HTML : LT_NONE,
 				lfi.fontsize, lfi.fontname, lfi.fontcolor);
 	GD_has_labels(sg) |= TAIL_LABEL;
     }
@@ -780,14 +772,14 @@ void compute_bb(graph_t * g)
     pointf ptf, s2;
     int i, j;
 
-    if ((agnnodes(g) == 0) && (GD_n_cluster(g) ==0)) {
-	bb.LL = pointfof(0, 0);
-	bb.UR = pointfof(0, 0);
+    if (agnnodes(g) == 0 && GD_n_cluster(g) == 0) {
+	bb.LL = (pointf){0};
+	bb.UR = (pointf){0};
 	return;
     }
 
-    bb.LL = pointfof(INT_MAX, INT_MAX);
-    bb.UR = pointfof(-INT_MAX, -INT_MAX);
+    bb.LL = (pointf){INT_MAX, INT_MAX};
+    bb.UR = (pointf){-INT_MAX, -INT_MAX};
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	ptf = coord(n);
 	s2.x = ND_xsize(n) / 2.0;
@@ -922,7 +914,7 @@ static int cmpItem(Dt_t * d, void *p1[], void *p2[], Dtdisc_t * disc)
 static void *newItem(Dt_t * d, item * objp, Dtdisc_t * disc)
 {
     (void)d;
-    item *newp = NEW(item);
+    item *newp = gv_alloc(sizeof(item));
 
     (void)disc;
     newp->p[0] = objp->p[0];
@@ -1156,7 +1148,7 @@ static node_t *mapN(node_t * n, graph_t * clg)
     graph_t *g = agraphof(n);
     Agsym_t *sym;
 
-    if (!(IS_CLUST_NODE(n)))
+    if (!IS_CLUST_NODE(n))
 	return n;
     agsubnode(clg, n, 1);
     name = strchr(agnameof(n), ':');
@@ -1213,24 +1205,23 @@ void undoClusterEdges(graph_t * g)
     node_t *nextn;
     edge_t *e;
     graph_t *clg;
-    edge_t **elist;
     int ecnt = num_clust_edges(g);
     int i = 0;
 
     if (!ecnt) return;
     clg = agsubg(g, "__clusternodes",1);
     agbindrec(clg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
-    elist = N_NEW(ecnt, edge_t*);
+    edge_t **edgelist = gv_calloc(ecnt, sizeof(edge_t*));
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
 	    if (ED_compound(e))
-		elist[i++] = e;
+		edgelist[i++] = e;
 	}
     }
     assert(i == ecnt);
     for (i = 0; i < ecnt; i++)
-	undoCompound(elist[i], clg);
-    free (elist);
+	undoCompound(edgelist[i], clg);
+    free (edgelist);
     for (n = agfstnode(clg); n; n = nextn) {
 	nextn = agnxtnode(clg, n);
 	gv_cleanup_node(n);
@@ -1242,14 +1233,12 @@ void undoClusterEdges(graph_t * g)
 /* safe_dcl:
  * Find the attribute belonging to graph g for objects like obj
  * with given name. If one does not exist, create it with the
- * default value def.
+ * default value defaultValue.
  */
-attrsym_t*
-safe_dcl(graph_t * g, int obj_kind, char *name, char *def)
-{
+attrsym_t *safe_dcl(graph_t *g, int obj_kind, char *name, char *defaultValue) {
     attrsym_t *a = agattr(g,obj_kind,name, NULL);
     if (!a)	/* attribute does not exist */
-	a = agattr(g,obj_kind,name,def);
+        a = agattr(g, obj_kind, name, defaultValue);
     return a;
 }
 
@@ -1268,12 +1257,12 @@ char* scanEntity (char* t, agxbuf* xb)
 {
     char*  endp = strchr (t, ';');
     struct entities_s key, *res;
-    int    len;
+    size_t len;
     char   buf[MAXENTLEN+1];
 
     agxbputc(xb, '&');
     if (!endp) return t;
-    if (((len = endp-t) > MAXENTLEN) || (len < 2)) return t;
+    if ((len = (size_t)(endp - t)) > MAXENTLEN || len < 2) return t;
     strncpy (buf, t, len);
     buf[len] = '\0';
     key.name =  buf;
@@ -1281,7 +1270,7 @@ char* scanEntity (char* t, agxbuf* xb)
         sizeof(entities[0]), comp_entities);
     if (!res) return t;
     agxbprint(xb, "#%d;", res->value);
-    return (endp+1);
+    return endp + 1;
 }
 
 
@@ -1316,14 +1305,14 @@ htmlEntity (char** s)
                     byte = byte - '0';
 		else
                     break;
-		n = (n * 16) + (int)byte;
+		n = n * 16 + (int)byte;
 	    }
 	}
 	else {
 	    for (i = 1; i < 8; i++) {
 		byte = *(str + i);
 		if (byte >= '0' && byte <= '9')
-		    n = (n * 10) + ((int)byte - '0');
+		    n = n * 10 + ((int)byte - '0');
 		else
 		    break;
 	    }
@@ -1361,15 +1350,13 @@ static unsigned char
 cvtAndAppend (unsigned char c, agxbuf* xb)
 {
     char buf[2];
-    char* s;
-    char* p;
-    int len;
 
     buf[0] = c;
     buf[1] = '\0';
 
-    p = s = latin1ToUTF8 (buf);
-    len = strlen(s);
+    char *s = latin1ToUTF8(buf);
+    char *p = s;
+    size_t len = strlen(s);
     while (len-- > 1)
 	agxbputc(xb, *p++);
     c = *p;
@@ -1468,7 +1455,7 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
 char* latin1ToUTF8 (char* s)
 {
     agxbuf xb = {0};
-    unsigned int  v;
+    unsigned int v;
 
     /* Values are either a byte (<= 256) or come from htmlEntity, whose
      * values are all less than 0x07FF, so we need at most 3 bytes.
@@ -1503,34 +1490,28 @@ utf8ToLatin1 (char* s)
 {
     agxbuf xb = {0};
     unsigned char c;
-    unsigned char outc;
 
     while ((c = *(unsigned char*)s++)) {
 	if (c < 0x7F)
 	    agxbputc(&xb, (char)c);
 	else {
-	    outc = (c & 0x03) << 6;
-	    c = *(unsigned char*)s++;
-	    outc = outc | (c & 0x3F);
+            unsigned char outc = (c & 0x03) << 6;
+            c = *(unsigned char *)s++;
+            outc = outc | (c & 0x3F);
 	    agxbputc(&xb, (char)outc);
 	}
     }
     return agxbdisown(&xb);
 }
 
-bool overlap_node(node_t *n, boxf b)
-{
-    inside_t ictxt;
-    pointf p;
-
+bool overlap_node(node_t *n, boxf b) {
     if (! OVERLAP(b, ND_bb(n)))
         return false;
 
-/*  FIXME - need to do something better about CLOSEENOUGH */
-    p = sub_pointf(ND_coord(n), mid_pointf(b.UR, b.LL));
+    /*  FIXME - need to do something better about CLOSEENOUGH */
+    pointf p = sub_pointf(ND_coord(n), mid_pointf(b.UR, b.LL));
 
-    ictxt.s.n = n;
-    ictxt.s.bp = NULL;
+    inside_t ictxt = {.s.n = n};
 
     return ND_shape(n)->fns->insidefn(&ictxt, p);
 }
@@ -1538,12 +1519,9 @@ bool overlap_node(node_t *n, boxf b)
 bool overlap_label(textlabel_t *lp, boxf b)
 {
     pointf s;
-    boxf bb;
-
     s.x = lp->dimen.x / 2.;
     s.y = lp->dimen.y / 2.;
-    bb.LL = sub_pointf(lp->pos, s);
-    bb.UR = add_pointf(lp->pos, s);
+    boxf bb = {.LL = sub_pointf(lp->pos, s), .UR = add_pointf(lp->pos, s)};
     return OVERLAP(b, bb);
 }
 
@@ -1553,17 +1531,13 @@ static bool overlap_arrow(pointf p, pointf u, double scale, boxf b)
     return OVERLAP(b, arrow_bb(p, u, scale));
 }
 
-static bool overlap_bezier(bezier bz, boxf b)
-{
-    int i;
-    pointf p, u;
-
+static bool overlap_bezier(bezier bz, boxf b) {
     assert(bz.size);
-    u = bz.list[0];
-    for (i = 1; i < bz.size; i++) {
-	p = bz.list[i];
-	if (lineToBox(p, u, b) != -1)
-	    return true;
+    pointf u = bz.list[0];
+    for (int i = 1; i < bz.size; i++) {
+        pointf p = bz.list[i];
+        if (lineToBox(p, u, b) != -1)
+            return true;
 	u = p;
     }
 
@@ -1581,17 +1555,13 @@ static bool overlap_bezier(bezier bz, boxf b)
 
 bool overlap_edge(edge_t *e, boxf b)
 {
-    int i;
-    splines *spl;
-    textlabel_t *lp;
-
-    spl = ED_spl(e);
+    splines *spl = ED_spl(e);
     if (spl && boxf_overlap(spl->bb, b))
-        for (i = 0; i < spl->size; i++)
+        for (int i = 0; i < spl->size; i++)
             if (overlap_bezier(spl->list[i], b))
                 return true;
 
-    lp = ED_label(e);
+    textlabel_t *lp = ED_label(e);
     if (lp && overlap_label(lp, b))
         return true;
 
@@ -1601,10 +1571,9 @@ bool overlap_edge(edge_t *e, boxf b)
 /* edgeType:
  * Convert string to edge type.
  */
-static int edgeType(const char *s, int dflt)
-{
+static int edgeType(const char *s, int defaultValue) {
     if (s == NULL || strcmp(s, "") == 0) {
-	return dflt;
+        return defaultValue;
     }
 
     if (*s == '0') { /* false */
@@ -1636,12 +1605,12 @@ static int edgeType(const char *s, int dflt)
     }
 
     agerr(AGWARN, "Unknown \"splines\" value: \"%s\" - ignored\n", s);
-    return dflt;
+    return defaultValue;
 }
 
 /* setEdgeType:
  * Sets graph's edge type based on the "splines" attribute.
- * If the attribute is not defined, use default.
+ * If the attribute is not defined, use defaultValue.
  * If the attribute is "", use NONE.
  * If attribute value matches (case indepedent), use match.
  *   ortho => EDGETYPE_ORTHO
@@ -1649,25 +1618,24 @@ static int edgeType(const char *s, int dflt)
  *   line => EDGETYPE_LINE
  *   polyline => EDGETYPE_PLINE
  *   spline => EDGETYPE_SPLINE
- * If attribute is boolean, true means EDGETYPE_SPLINE, false means EDGETYPE_LINE.
- * Else warn and use default.
+ * If attribute is boolean, true means EDGETYPE_SPLINE, false means
+ * EDGETYPE_LINE. Else warn and use default.
  */
-void setEdgeType (graph_t* g, int dflt)
-{
+void setEdgeType(graph_t *g, int defaultValue) {
     char* s = agget(g, "splines");
     int et;
 
     if (!s) {
-	et = dflt;
+        et = defaultValue;
     }
     else if (*s == '\0') {
 	et = EDGETYPE_NONE;
+    } else {
+        et = edgeType(s, defaultValue);
     }
-    else et = edgeType (s, dflt);
     GD_flags(g) |= et;
 }
 
-
 /* get_gradient_points
  * Evaluates the extreme points of an ellipse or polygon
  * Determines the point at the center of the extreme points
@@ -1678,28 +1646,26 @@ void setEdgeType (graph_t* g, int dflt)
  * is set, use standard coordinate system.
  */
 void get_gradient_points(pointf *A, pointf *G, int n, double angle, int flags) {
-    int i;
-    double rx, ry;
     pointf min,max,center;
     int isRadial = flags & 1;
     int isRHS = flags & 2;
 
     if (n == 2) {
-      rx = A[1].x - A[0].x;
-      ry = A[1].y - A[0].y;
-      min.x = A[0].x - rx;
-      max.x = A[0].x + rx;
-      min.y = A[0].y - ry;
-      max.y = A[0].y + ry;
+        double rx = A[1].x - A[0].x;
+        double ry = A[1].y - A[0].y;
+        min.x = A[0].x - rx;
+        max.x = A[0].x + rx;
+        min.y = A[0].y - ry;
+        max.y = A[0].y + ry;
     }
     else {
       min.x = max.x = A[0].x;
       min.y = max.y = A[0].y;
-      for (i = 0; i < n; i++){
-	min.x = MIN(A[i].x,min.x);
-	min.y = MIN(A[i].y,min.y);
-	max.x = MAX(A[i].x,max.x);
-	max.y = MAX(A[i].y,max.y);
+      for (int i = 0; i < n; i++) {
+            min.x = MIN(A[i].x, min.x);
+            min.y = MIN(A[i].y, min.y);
+            max.x = MAX(A[i].x, max.x);
+            max.y = MAX(A[i].y, max.y);
       }
     }
       center.x = min.x + (max.x - min.x)/2;
@@ -1736,11 +1702,9 @@ void get_gradient_points(pointf *A, pointf *G, int n, double angle, int flags) {
     }
 }
 
-void gv_free_splines(edge_t * e)
-{
-    int i;
+void gv_free_splines(edge_t *e) {
     if (ED_spl(e)) {
-        for (i = 0; i < ED_spl(e)->size; i++)
+        for (int i = 0; i < ED_spl(e)->size; i++)
             free(ED_spl(e)->list[i].list);
         free(ED_spl(e)->list);
         free(ED_spl(e));
@@ -1750,14 +1714,14 @@ void gv_free_splines(edge_t * e)
 
 void gv_cleanup_edge(edge_t * e)
 {
-    free (ED_path(e).ps);
+    free(ED_path(e).ps);
     gv_free_splines(e);
     free_label(ED_label(e));
     free_label(ED_xlabel(e));
     free_label(ED_head_label(e));
     free_label(ED_tail_label(e));
-	/*FIX HERE , shallow cleaning may not be enough here */
-	agdelrec(e, "Agedgeinfo_t");
+    /*FIX HERE , shallow cleaning may not be enough here */
+    agdelrec(e, "Agedgeinfo_t");
 }
 
 void gv_cleanup_node(node_t * n)
@@ -1767,21 +1731,18 @@ void gv_cleanup_node(node_t * n)
         ND_shape(n)->fns->freefn(n);
     free_label(ND_label(n));
     free_label(ND_xlabel(n));
-	/*FIX HERE , shallow cleaning may not be enough here */
-	agdelrec(n, "Agnodeinfo_t");
+    /*FIX HERE , shallow cleaning may not be enough here */
+    agdelrec(n, "Agnodeinfo_t");
 }
 
-void gv_nodesize(node_t * n, bool flip)
-{
-    double w;
-
+void gv_nodesize(node_t *n, bool flip) {
     if (flip) {
-        w = INCH2PS(ND_height(n));
+        double w = INCH2PS(ND_height(n));
         ND_lw(n) = ND_rw(n) = w / 2;
         ND_ht(n) = INCH2PS(ND_width(n));
     }
     else {
-        w = INCH2PS(ND_width(n));
+        double w = INCH2PS(ND_width(n));
         ND_lw(n) = ND_rw(n) = w / 2;
         ND_ht(n) = INCH2PS(ND_height(n));
     }
@@ -1806,7 +1767,7 @@ static void free_clust (Dt_t* dt, clust_t* clp, Dtdisc_t* disc)
 {
     (void)dt;
     (void)disc;
-    free (clp);
+    free(clp);
 }
 
 static Dtdisc_t strDisc = {
@@ -1818,24 +1779,18 @@ static Dtdisc_t strDisc = {
 
 static void fillMap (Agraph_t* g, Dt_t* map)
 {
-    Agraph_t* cl;
-    int c;
-    char* s;
-    clust_t* ip;
-
-    for (c = 1; c <= GD_n_cluster(g); c++) {
-	cl = GD_clust(g)[c];
-	s = agnameof(cl);
-	if (dtmatch (map, s)) {
-	    agerr(AGWARN, "Two clusters named %s - the second will be ignored\n", s);
-	}
-	else {
-	    ip = NEW(clust_t);
-	    ip->name = s;
-	    ip->clp = cl;
+    for (int c = 1; c <= GD_n_cluster(g); c++) {
+        Agraph_t *cl = GD_clust(g)[c];
+        char *s = agnameof(cl);
+        if (dtmatch(map, s)) {
+            agerr(AGWARN, "Two clusters named %s - the second will be ignored\n", s);
+        } else {
+            clust_t *ip = gv_alloc(sizeof(clust_t));
+            ip->name = s;
+            ip->clp = cl;
 	    dtinsert (map, ip);
-	}
-	fillMap (cl, map);
+        }
+        fillMap (cl, map);
     }
 }
 
@@ -1862,3 +1817,8 @@ findCluster (Dt_t* map, char* name)
     else
 	return NULL;
 }
+
+/**
+ * @dir lib/common
+ * @brief common code for layout engines
+ */
