@@ -7,8 +7,8 @@
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
-#ifndef GLCOMPDEFS_H
-#define GLCOMPDEFS_H
+
+#pragma once
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -20,51 +20,47 @@
 #include <winuser.h>
 #include <tchar.h>
 #endif
-#include <GL/gl.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <GL/gl.h>
-#include <GL/glu.h>
+#include <glcomp/opengl.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 
-#define	GLCOMPSET_PANEL_COLOR_R		(GLfloat)0.16
-#define	GLCOMPSET_PANEL_COLOR_G		(GLfloat)0.44
-#define	GLCOMPSET_PANEL_COLOR_B		(GLfloat)0.87
-#define	GLCOMPSET_PANEL_COLOR_ALPHA	(GLfloat)0.5
-#define	GLCOMPSET_PANEL_SHADOW_COLOR_R		(GLfloat)0
-#define	GLCOMPSET_PANEL_SHADOW_COLOR_G		(GLfloat)0
-#define	GLCOMPSET_PANEL_SHADOW_COLOR_B		(GLfloat)0
-#define	GLCOMPSET_PANEL_SHADOW_COLOR_A		(GLfloat)0.3
-#define GLCOMPSET_PANEL_SHADOW_WIDTH		(GLfloat)4
+#define	GLCOMPSET_PANEL_COLOR_R		0.16f
+#define	GLCOMPSET_PANEL_COLOR_G		0.44f
+#define	GLCOMPSET_PANEL_COLOR_B		0.87f
+#define	GLCOMPSET_PANEL_COLOR_ALPHA	0.5f
+#define	GLCOMPSET_PANEL_SHADOW_COLOR_R		0.0f
+#define	GLCOMPSET_PANEL_SHADOW_COLOR_G		0.0f
+#define	GLCOMPSET_PANEL_SHADOW_COLOR_B		0.0f
+#define	GLCOMPSET_PANEL_SHADOW_COLOR_A		0.3f
+#define GLCOMPSET_PANEL_SHADOW_WIDTH		4.0f
 
-#define	GLCOMPSET_BUTTON_COLOR_R		(GLfloat)0
-#define	GLCOMPSET_BUTTON_COLOR_G		(GLfloat)1
-#define	GLCOMPSET_BUTTON_COLOR_B		(GLfloat)0.3
-#define	GLCOMPSET_BUTTON_COLOR_ALPHA	(GLfloat)0.6
-#define	GLCOMPSET_BUTTON_THICKNESS		(GLfloat)3
-#define	GLCOMPSET_BUTTON_BEVEL_BRIGHTNESS		(GLfloat)1.7
-#define GLCOMPSET_FONT_SIZE				(GLfloat)14
+#define	GLCOMPSET_BUTTON_COLOR_R		0.0f
+#define	GLCOMPSET_BUTTON_COLOR_G		1.0f
+#define	GLCOMPSET_BUTTON_COLOR_B		0.3f
+#define	GLCOMPSET_BUTTON_COLOR_ALPHA	0.6f
+#define	GLCOMPSET_BUTTON_THICKNESS		3.0f
+#define	GLCOMPSET_BUTTON_BEVEL_BRIGHTNESS		1.7f
+#define GLCOMPSET_FONT_SIZE				14.0f
 
-#define	GLCOMPSET_BUTTON_FONT_COLOR_R		(GLfloat)0
-#define	GLCOMPSET_BUTTON_FONT_COLOR_G		(GLfloat)0
-#define	GLCOMPSET_BUTTON_FONT_COLOR_B		(GLfloat)0
-#define	GLCOMPSET_BUTTON_FONT_COLOR_ALPHA	(GLfloat)1
+#define	GLCOMPSET_BUTTON_FONT_COLOR_R		0.0f
+#define	GLCOMPSET_BUTTON_FONT_COLOR_G		0.0f
+#define	GLCOMPSET_BUTTON_FONT_COLOR_B		0.0f
+#define	GLCOMPSET_BUTTON_FONT_COLOR_ALPHA	1.0f
 
-#define GLCOMPSET_FONT_SIZE_FACTOR			(GLfloat)0.7
+#define GLCOMPSET_FONT_SIZE_FACTOR			0.7f
 
-#define	GLCOMPSET_LABEL_COLOR_R		(GLfloat)0
-#define	GLCOMPSET_LABEL_COLOR_G		(GLfloat)0
-#define	GLCOMPSET_LABEL_COLOR_B		(GLfloat)0
-#define	GLCOMPSET_LABEL_COLOR_ALPHA	(GLfloat)1
+#define	GLCOMPSET_LABEL_COLOR_R		0.0f
+#define	GLCOMPSET_LABEL_COLOR_G		0.0f
+#define	GLCOMPSET_LABEL_COLOR_B		0.0f
+#define	GLCOMPSET_LABEL_COLOR_ALPHA	1.0f
 
-#define	GLCOMPSET_FONT_COLOR_R		(GLfloat)0
-#define	GLCOMPSET_FONT_COLOR_G		(GLfloat)0
-#define	GLCOMPSET_FONT_COLOR_B		(GLfloat)0
-#define	GLCOMPSET_FONT_COLOR_ALPHA	(GLfloat)1
+#define	GLCOMPSET_FONT_COLOR_R		0.0f
+#define	GLCOMPSET_FONT_COLOR_G		0.0f
+#define	GLCOMPSET_FONT_COLOR_B		0.0f
+#define	GLCOMPSET_FONT_COLOR_ALPHA	1.0f
 #define GLCOMPSET_FONT_DESC  "Times Italic"
 #define GL_FONTOPTIMIZE 1
 
@@ -75,24 +71,13 @@ extern "C" {
 
 #define DEFAULT_GLUT_FONT GLUT_BITMAP_HELVETICA_12
 
-#define GLCOMPSET_BORDERWIDTH				(GLfloat)2
-#define GLCOMPSET_PANEL_BORDERWIDTH				(GLfloat)3
-#define GLCOMPSET_BUTTON_BEVEL				(GLfloat)5
-#define	GLCOMPSET_BEVEL_DIFF				(GLfloat)0.001
-#define GLCOMPSET_DEFAULT_PAD		(GLfloat)3
-#define	GLCOMP_DEFAULT_WIDTH	(GLfloat)10
-#define	GLCOMP_DEFAULT_HEIGHT	(GLfloat)10
+#define GLCOMPSET_BORDERWIDTH				2.0f
+#define GLCOMPSET_PANEL_BORDERWIDTH				3.0f
+#define GLCOMPSET_BUTTON_BEVEL				5.0f
+#define	GLCOMPSET_BEVEL_DIFF				0.001f
+#define	GLCOMP_DEFAULT_WIDTH	10.0f
+#define	GLCOMP_DEFAULT_HEIGHT	10.0f
 
-
-
-#define FONT_MAX_LEN                1024	/* maximum chars to draw to the screen, used for buffers also */
-#define FONT_TAB_SPACE              4	/* spaces to draw for a tab, make option? */
-
-#define C_DPI              16
-#define R_DPI              16
-
-    typedef enum { inverted_y, scientific_y } glCompOrientation;
-    typedef enum { gluttext, pangotext } glCompFontType;
     typedef enum { glAlignNone, glAlignLeft, glAlignTop, glAlignBottom,
 	    glAlignRight, glAlignParent, glAlignCenter } glCompAlignment;
 
@@ -100,10 +85,6 @@ extern "C" {
 	    glFontVJustifyBottom, glFontVJustifyCenter } glCompVJustify;
     typedef enum { glFontHJustifyNone, glFontHJustifyLeft,
 	    glFontHJustifyRight, glFontHJustifyCenter } glCompHJustify;
-    typedef enum { glButtonGlyphLeft, glButtonGlyphRight, glButtonGlyphTop,
-	    glButtonGlyphBottom } glCompButtonGlyph;
-    typedef enum { glBorderNone, glBorderSolid, glBorderBevel,
-	    glBorderCustom } glCompBorderType;
 
     typedef enum { glMouseDown, glMouseUp } glCompMouseStatus;
     typedef enum { glMouseLeftButton, glMouseRightButton,
@@ -166,12 +147,8 @@ extern "C" {
 	GLfloat x, y, z;
     } glCompPoint;
 
-    typedef struct _glCompPointI {
-	int x, y;
-    } glCompPointI;
     typedef struct {
 	int cnt;
-	int hotKey;
 	glCompPoint* pts;
     }glCompPoly;
 
@@ -180,8 +157,6 @@ extern "C" {
 	GLfloat G;
 	GLfloat B;
 	GLfloat A;		//Alpha
-	int tag;
-	int test;
     } glCompColor;
 
 
@@ -209,7 +184,6 @@ extern "C" {
     typedef struct {
 	char *fontdesc;		//font description , only used with pango fonts
 	glCompColor color;
-	glCompFontType type;
 	void *glutfont;		/*glut font pointer if used */
 	int transparent;
 	glCompTex *tex;		/* texture, if type is pangotext */
@@ -243,7 +217,6 @@ extern "C" {
 	glCompPoint refPos;	/*calculated pos after anchors and aligns */
 	GLfloat width, height;
 	GLfloat borderWidth;
-	glCompBorderType borderType;
 	glCompColor color;
 	int enabled;
 	int visible;
@@ -283,7 +256,6 @@ extern "C" {
     typedef struct _glCompLabel {
 	glObjType objType;	/*always keep this here for each drawable object */
 	glCompCommon common;
-	int autosize;		/*if 1 label sized is calculated from font */
 	char *text;
 	int transparent;
     } glCompLabel;
@@ -298,47 +270,12 @@ extern "C" {
 	int refStatus;		//0 not pressed 1 pressed;
 	int groupid;
 	glCompImage *image;	/*glyph */
-	glCompButtonGlyph glyphPos;
-	void *customptr;	//general purpose void pointer to pass to call back
 	int data;
 
     };
 
 /*texture based image*/
 
-/*track bar*/
-    typedef struct _glCompTrackBar {
-	glObjType objType;	/*always keep this here for each drawable object */
-	GLfloat width, height;
-	glCompPanel *outerpanel;
-	glCompPanel *trackline;
-	glCompPanel *indicator;
-
-	GLfloat bevel;
-	glCompColor color;
-	glCompColor shadowcolor;
-
-
-	float value;
-	float maxvalue;
-	float minvalue;
-	int enabled;
-	int visible;
-	void *parentset;	//parent compset
-	int data;
-	glCompFont *font;	//pointer to font to use
-	glCompOrientation orientation;
-
-    } glCompTrackBar;
-
-/*glCompFont container class*/
-    typedef struct {
-	glCompFont **fonts;
-	int count;
-	int activefont;
-	char *font_directory;	//location where the glfont files are stored
-    } fontset_t;
-
 /*object prototype*/
     struct _glCompObj {
 	glObjType objType;
@@ -389,4 +326,3 @@ extern "C" {
 #ifdef __cplusplus
 }
 #endif
-#endif
