@@ -100,12 +100,6 @@ def test_56():
   input = Path(__file__).parent / "56.dot"
   assert input.exists(), "unexpectedly missing test case"
 
-  # FIXME: remove this block when this #56 is fixed
-  if not is_ndebug_defined() and platform.system() != "Windows":
-    with pytest.raises(subprocess.CalledProcessError):
-      dot("svg", input)
-    return
-
   # process it with Graphviz
   dot("svg", input)
 
@@ -607,6 +601,26 @@ def test_1594():
   assert "line 3:" in stderr, \
     "GVPR did not identify correct line of syntax error"
 
+@pytest.mark.parametrize("long,short", (("--help", "-?"),
+                                        ("--version", "-V")))
+def test_1618(long: str, short: str):
+  """
+  Graphviz should understand `--help` and `--version`
+  https://gitlab.com/graphviz/graphviz/-/issues/1618
+  """
+
+  # run Graphviz with the short form of the argument
+  p1 = subprocess.run(["dot", short], stdout=subprocess.PIPE,
+                      stderr=subprocess.PIPE, check=True)
+
+  # run it with the long form of the argument
+  p2 = subprocess.run(["dot", long], stdout=subprocess.PIPE,
+                      stderr=subprocess.PIPE, check=True)
+
+  # output from both should match
+  assert p1.stdout == p2.stdout, f"`dot {long}` wrote output than `dot {short}`"
+  assert p1.stderr == p2.stderr, f"`dot {long}` wrote output than `dot {short}`"
+
 @pytest.mark.xfail(strict=True)
 def test_1624():
   """
@@ -894,12 +908,6 @@ def test_1880():
   input = Path(__file__).parent / "1880.dot"
   assert input.exists(), "unexpectedly missing test case"
 
-  # FIXME: remove this block when this #1880 is fixed
-  if not is_ndebug_defined() and platform.system() != "Windows":
-    with pytest.raises(subprocess.CalledProcessError):
-      dot("png", input)
-    return
-
   # process it with Graphviz
   dot("png", input)
 
@@ -1985,6 +1993,21 @@ def test_2272():
   # run the test
   run_c(c_src, link=["cgraph", "gvc"])
 
+def test_2272_2():
+  """
+  An unterminated string in the source should not crash Graphviz. Variant of
+  `test_2272`.
+  """
+
+  # a graph with an open string
+  graph = 'graph { a[label="abc'
+
+  # process it with Graphviz, which should not crash
+  p = subprocess.run(["dot", "-o", os.devnull], input=graph,
+                     universal_newlines=True)
+  assert p.returncode != 0, "dot accepted invalid input"
+  assert p.returncode == 1, "dot crashed"
+
 def test_2282():
   """
   using the `fdp` layout with JSON output should result in valid JSON
@@ -2043,3 +2066,31 @@ def test_2307():
       continue
     assert re.search(r"\bG2_", m.group("url")) is not None, \
       "ID G2 was not applied to polygon fill url"
+
+def test_2325():
+  """
+  using more than 63 styles and/or more than 128 style bytes should not trigger
+  an out-of-bounds memory read
+  https://gitlab.com/graphviz/graphviz/-/issues/2325
+  """
+
+  # locate our associated test case in this directory
+  input = Path(__file__).parent / "2325.dot"
+  assert input.exists(), "unexpectedly missing test case"
+
+  # run it through Graphviz
+  dot("svg", input)
+
+def test_changelog_dates():
+  """
+  Check the dates of releases in the changelog are correctly formatted
+  """
+  changelog = Path(__file__).parent / "../CHANGELOG.md"
+  with open(changelog, "rt", encoding="utf-8") as f:
+    for lineno, line in enumerate(f, 1):
+      m = re.match(r"## \[\d+\.\d+\.\d+\] [-–] (?P<date>.*)$", line)
+      if m is None:
+        continue
+      d = re.match(r"\d{4}-\d{2}-\d{2}", m.group("date"))
+      assert d is not None, \
+        f"CHANGELOG.md:{lineno}: date in incorrect format: {line}"
